@@ -73,6 +73,9 @@ private slots:
     //! Invoked when the socket makes any transfers
     void onSocketXfer (qint64 bytesXfer, qint64 bytesTotal);
 
+    //! Any changes in NW calls into this
+    void onNwCfgChanged (const QNetworkConfiguration &config);
+
 private:
     QWebElement doc ();
     bool isLoggedIn ();
@@ -136,6 +139,8 @@ private:
     //! The current page (contacts or inbox)
     int                     nCurrent;
 
+    //! Mutex to protect variables
+    QMutex                  mutex;
     //! We use this to check if we're online
     QNetworkConfigurationManager *nwCfg;
 
